@@ -1,22 +1,19 @@
 #!/usr/bin/perl -w
-#$Id: device.pl,v 1.5 2006/02/13 15:28:31 rocky Exp $
 #
-#    Copyright (C) 2006 Rocky Bernstein <rocky@cpan.org>
+#  Copyright (C) 2006, 2008, 2011 Rocky Bernstein <rocky@cpan.org>
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
 #
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Program to read CD blocks. See read-cd from the libcdio distribution
 # for a more complete program.
@@ -34,8 +31,6 @@ use vars qw($0 $program $pause %opts);
 
 use strict;
 
-my $vcid ='$Id: device.pl,v 1.5 2006/02/13 15:28:31 rocky Exp $';
-
 # Prints out drive capabilities
 sub print_drive_capabilities($$$) {
     my ($i_read_cap, $i_write_cap, $i_misc_cap) = @_;
