@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
-#  Copyright (C) 2006, 2008 Rocky Bernstein <rocky@cpan.org>
-#  
+#  Copyright (C) 2006, 2008, 2017 Rocky Bernstein <rocky@cpan.org>
+#
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
@@ -36,6 +36,14 @@ use Device::Cdio::ISO9660;
 use Device::Cdio::ISO9660::IFS;
 use File::Spec;
 
+sub tm2str($) {
+    my $tm = shift;
+    return sprintf("%s %02d %s %s:%s:%s",
+		   qw(Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec")[$tm->{mon}-1],
+		   $tm->{mday}, $tm->{year},
+	           $tm->{hour}, $tm->{min}, $tm->{sec});
+}
+
 # The default ISO 9660 image if none given
 my $ISO9660_IMAGE_PATH="../data";
 my $ISO9660_IMAGE=File::Spec->catfile($ISO9660_IMAGE_PATH, "copying.iso");
@@ -44,7 +52,7 @@ my $iso_image_fname = $ISO9660_IMAGE;
 $iso_image_fname = $ARGV[0] if @ARGV >= 1;
 
 my $iso = Device::Cdio::ISO9660::IFS->new(-source=>$iso_image_fname);
-  
+
 if (!defined($iso)) {
     printf "Sorry, couldn't open %s as an ISO-9660 image.\n", $iso_image_fname;
     exit 1;
@@ -71,15 +79,14 @@ printf "Volume ID: %s\n", $id if defined($id);
 $id = $iso->get_volumeset_id();
 printf "Volumeset ID: %s\n", $id if defined($id);
 
-foreach my $href (@file_stats) {    
-    printf "%s [LSN %6d] %8d %s%s\n", 
+foreach my $href (@file_stats) {
+    printf "%s [LSN %6d] %8d %s %s%s\n",
     $href->{is_dir} ? "d" : "-",
     $href->{LSN}, $href->{size},
+    tm2str($href->{tm}),
     $path,
     Device::Cdio::ISO9660::name_translate($href->{filename});
 }
-    
+
 $iso->close();
 exit 0;
-
-
